/* ver.B.b17.12(BLAZE) */


#include "version.h"


VERSION ap_version = {
	"AP.code",
	"addrdb",
	"(C) 2000-2008 Hirohisa Mori and GLOBALBASE Project",
	"ver.B.b17.12(BLAZE)",
	2009,7,30,
	0,
	"convert from Kiban to Matrix ",
};

